==> aroundme_0_6_5.zip: aroundme_0_6_5/aroundme/language/1/barnraiser_01/frm_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------



//SECTION
$lang['hdr_latest_subjects'] = 					"latest community discussions";
$lang['hdr_subject'] = 							"discussion";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_topics'] = 							"topics";
$lang['hdr_topic'] = 							"topic";
$lang['hdr_permissions'] = 						"permissions";
$lang['hdr_latest_comments'] = 					"latest comments";
$lang['hdr_group_subject'] = 					"group subject";
$lang['hdr_group_topic'] = 						"group topic";
$lang['hdr_options'] =							"discussion options";
$lang['hdr_subject_author'] = 					"author";
$lang['hdr_group_author'] = 					"authoring group";
$lang['hdr_my_group_subjects'] = 				"latest discussions from my groups";
$lang['hdr_my_network_subjects'] = 				"latest discussions from my network";


//A HREF TAGS (links)
$lang['href_group_subject'] = 					"view group discussions";
$lang['href_network_subject'] = 				"view their discussions";
$lang['href_view_node'] = 						"latest from the community";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_view_my_groups'] = 					"latest from my groups";
$lang['href_my_subjects'] = 					"my discussions";
$lang['href_marked'] = 							"marked subjects";
$lang['href_list_subjects'] = 					"list discussions";
$lang['href_add_subject'] = 					"add a discussion to this community";
$lang['href_group_add_subject'] = 				"add a discussion to this group";
$lang['href_add_topic'] = 						"add a topic to this community";
$lang['href_group_add_topic'] = 				"add a topic to this group";
$lang['href_edit_topics'] = 					"manage community topics";
$lang['href_edit_group_topics'] = 				"manage group topics";
$lang['href_add_subject_topic'] = 				"add a dicussion under this topic";

// ERR
$lang['err_no_topics'] = 						"Sorry, there are no topics to display.";
$lang['err_no_subjects'] = 						"Sorry, no discussions available.";
$lang['err_no_add_subject'] = 					"sorry, you are not allowed to add a discussion to this topic.";

//icons
$lang['ttl_sticky'] = 							"sticky";
$lang['ttl_locked'] = 							"locked";


//BODY TEXT
$lang['txt_topic'] = 							"topic";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag_intro'] = 						"My tags";
$lang['txt_item_tag'] = 						"This discussion is tagged with with";
$lang['txt_total_subjects'] = 					"total subjects";
$lang['txt_search_discussions'] = 				"search for discussions";
$lang['txt_comment_total'] = 					"total comments";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_last_comment'] = 					"last comment";
$lang['txt_topic_role_add'] = 					"The following roles can add subjects to this topic";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_locked'] = 							"locked";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_group_link'] = 						"This discussion is from the group";
$lang['txt_intro_group'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) discussions that have been published by the groups that you are a member of.";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) discussions that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) discussions that have been published by a person in your network.";
$lang['txt_outro_group'] = 						"The following groups have not published a discussion within the last SYS_KEYWORD_NUMBER.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a discussion within the last SYS_KEYWORD_NUMBER.";
$lang['txt_intro_latest'] = 					"These are the latest discussions for the community. If you want to add a discussion click on a topic first.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"discussions";

?>

==> aroundme_0_6_7.zip: aroundme_0_6_7/aroundme/language/1/barnraiser_01/frm_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------



//SECTION
$lang['hdr_latest_subjects'] = 					"latest community discussions";
$lang['hdr_subject'] = 							"discussion";
$lang['hdr_subjects'] = 						"subjects";
$lang['hdr_topics'] = 							"topics";
$lang['hdr_topic'] = 							"topic";
$lang['hdr_permissions'] = 						"permissions";
$lang['hdr_latest_comments'] = 					"latest comments";
$lang['hdr_group_subject'] = 					"group subject";
$lang['hdr_group_topic'] = 						"group topic";
$lang['hdr_options'] =							"discussion options";
$lang['hdr_subject_author'] = 					"author";
$lang['hdr_group_author'] = 					"authoring group";
$lang['hdr_my_group_subjects'] = 				"latest discussions from my groups";
$lang['hdr_my_network_subjects'] = 				"latest discussions from my network";


//A HREF TAGS (links)
$lang['href_group_subject'] = 					"view group discussions";
$lang['href_network_subject'] = 				"view their discussions";
$lang['href_view_node'] = 						"latest from the community";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_view_my_groups'] = 					"latest from my groups";
$lang['href_my_subjects'] = 					"my discussions";
$lang['href_marked'] = 							"marked subjects";
$lang['href_tipped'] = 							"tipped subjects";
$lang['href_list_subjects'] = 					"list discussions";
$lang['href_add_subject'] = 					"add a discussion to this community";
$lang['href_group_add_subject'] = 				"add a discussion to this group";
$lang['href_add_topic'] = 						"add a topic to this community";
$lang['href_group_add_topic'] = 				"add a topic to this group";
$lang['href_edit_topics'] = 					"manage community topics";
$lang['href_edit_group_topics'] = 				"manage group topics";
$lang['href_add_subject_topic'] = 				"add a dicussion under this topic";

// ERR
$lang['err_no_topics'] = 						"Sorry, there are no topics to display.";
$lang['err_no_subjects'] = 						"Sorry, no discussions available.";
$lang['err_no_add_subject'] = 					"sorry, you are not allowed to add a discussion to this topic.";

//icons
$lang['ttl_sticky'] = 							"sticky";
$lang['ttl_locked'] = 							"locked";


//BODY TEXT
$lang['txt_topic'] = 							"topic";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag_intro'] = 						"My tags";
$lang['txt_item_tag'] = 						"This discussion is tagged with with";
$lang['txt_total_subjects'] = 					"total subjects";
$lang['txt_search_discussions'] = 				"search for discussions";
$lang['txt_comment_total'] = 					"total comments";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_last_comment'] = 					"last comment";
$lang['txt_topic_role_add'] = 					"The following roles can add subjects to this topic";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_locked'] = 							"locked";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_group_link'] = 						"This discussion is from the group";
$lang['txt_intro_group'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) discussions that have been published by the groups that you are a member of.";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) discussions that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) discussions that have been published by a person in your network.";
$lang['txt_outro_group'] = 						"The following groups have not published a discussion within the last SYS_KEYWORD_NUMBER.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a discussion within the last SYS_KEYWORD_NUMBER.";
$lang['txt_intro_latest'] = 					"These are the latest discussions for the community. If you want to add a discussion click on a topic first.";
$lang['txt_intro_marked'] = 					"You have bookmarked the following items for reading. You can manage your bookmarks under 'Me', 'marks &amp; tips'.";
$lang['txt_intro_tipped'] = 					"Your network have recommended (tipped) the following items for reading. You can manage your recommendations to your network under 'Me', 'marks &amp; tips'.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"discussion";

?>
